@@ -6,7 +6,7 @@ use 5.008001;
 use File::ShareDir::Dist ();
 
 # ABSTRACT: Alien::libt2t
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 sub new
@@ -18,7 +18,9 @@ sub new
 
 sub dist_dir
 {
-  File::ShareDir::Dist::dist_share('Test2-Tools-FFI');
+  my $dir = File::ShareDir::Dist::dist_share('Test2-Tools-FFI');
+  $dir =~ s{\\}{/}g if $^O eq 'MSWin32';
+  $dir;
 }
 
 
@@ -51,7 +53,7 @@ Alien::libt2t - Alien::libt2t
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
